#################################################################
### 			 Cost analysis of the PADIN program in Brazil				###
###    This is a master file to run all three coding files    ###
###                 Created by: Yilin Pan                     ###
###	         	      Date: January 29, 2025	  	              ###
#################################################################

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 0. Purposes
#----------------------------------------------------------------------------------------------------------------------------------------------------------
## This file contains the master code for conducting the analysis presented 
## in the paper titled 'Costs, Cost-Sharing, and Cost Drivers of a Home 
## Visiting Program: The Case of PADIN in Brazil,' authored by Alaka Holla 
## and Yilin Pan.

## The inputs include 
## a) three coding files, all saved in the folder "./code":
##    1_Brazil_PADIN_data_cleaning.R,
##    2_Brazil_PADIN_variable_construction.R, and
##    3_Brazil_PADIN_analysis.R, and

## b) eight data files, with seven saved in the folder "./data/1_De-identified", 
##    and one saved in the folder "./data/2_Identified":
##    1. "./data/1_De-identified/survey_data_de-identified.csv"
##
##        This file contains Responses to a survey that elicits information 
##        on the time use and salaries of key personnel, transportation mode, 
##        frequencies of training for supervisors and home visitors, and 
##        frequency of community meetings for parents. 
##        The dataset is de-identified, and is included in the package. 
##        
##    2. "./data/1_De-identified/monitoring_and_evaluation_data_de-identified.csv"
##       This file contains Monitoring and evaluation (M&E) data, 
##       including the number of supervisors and home visitors by municipality. 
##       The datatset is de-identified, and is included in the package. 
## 
##    3. "./data/1_De-identified/state_budget_2018.csv"
##       This file contains PADIN financial spreadsheets on personnel, 
##       training, and food from the state government. 
##       This dataset contains aggregated data, and is included in the package. 
## 
##    4. "./data/1_De-identified/municipality_budget_de-identified.csv"
##       This file contains itemized monthly expenditure reports for office 
##       supplies and food from 20 municipalities. 
##       The dataset is de-identified and is included in the package. 
## 
##    5. "./data/1_De-identified/transportation_gps_de-identified.csv"
##       This file contains a simulated transportation profiles, 
##       represented as participating families by home visitor, 
##       neighborhood and municipality, as well as the travel distance 
##       and travel time estimated using GIS techniques 
##       (see Appendix B of the paper for details).
##       This file was simulated based on a confidential dataset not included 
##       in the package, which contains the number of families by neighborhood, 
##       home visitor, and municipality, provided by the PADIN team in SEDUC.
##       The dataset is de-identified, and is included in the package. 
##
##    6. "./data/1_De-identified/online_monitoring_de-identified.csv"
##       This file contains records from Online Monitoring System, including 
##       the number of supervisors, home visitors, families, children, visits 
##       and meetings by municipality. 
##       This dataset is de-identified, and is included in the package. 
## 
##    7. "./data/1_De-identified/municipality_statistics_de-identified.csv"
##       This file contains municipal statistics, including area, population size, 
##       and GDP per capita, with each municipality labeled using random numbers.
##       This dataset is used for the analysis, but will NOT be included in the package.
##       Since all the municipality statistics are public information, we will release the
##       dataset we compiled with municipality names (Dataset 8), and not our random 
##       numbers (Dataset 7) so that users cannot indirectly identify municipalities 
##       by matching this dataset with our other anonymized files.
##
##    8. "./data/2_Identified/Municipalities_statistics.csv"
##       This file contains municipal statistics, including area, population size, 
##       and GDP per capita, with each municipality labeled using municipality names.
##       This dataset is not used for the analysis, but will be included in the package.


## The output include
## a) five exhibits in the main text and six exhibits in Appendix A, 
##    all saved in folder "./output/1_Exhibits"
##    1. figure1_total_cost_funding.png: 
##       Figure 1. Cost per student per month, by funding source
##    2. figure2_total_cost_ingredient.png:
##       Figure 2. Cost per child per month, by ingredient and funding source
##    3. figure3_heatmap_m.png: 
##       Figure 3. Decomposition of cost per child per month borne 
##       by municipalities, by ingredient
##    4. figure4_supervisor.png: 
##       Figure 4. Supervisors' gross salary and time dedicated to 
##       the PADIN program
##    5. figure5_dumbbell_transportation.png:
##       Figure 5. The discrepancy between self-reported and transportation 
##       costs estimated with the ingredients method
##    6. figureA1_ADI_consistency.png:
##       Figure A1. Number of home visitors, by data source
##    7. figureA2_children_consistency.png:
##       Figure A2. Number of children served, by data source
##    8. figureA3_decomposition_state_cost.png:
##       Figure A3. State costs of the PADIN program, 
##       by ingredient (percentage of total state costs)
##    9. figureA4_total_cost_percentage.png:
##       Figure A4. Cost per child per month borne by funding source 
##       (percentage of total program costs)
##    10. figureA5_corr_spending_wealth.png: 
##       Figure A5. Correlation between Gross Domestic Product (GPD) 
##       per capita and cost per child per month borne by the municipality
##    11. figureA6_discrepancy: 
##        Figure A6. Deviation in the estimated cost per child per month 
##        from financial records compared to our estimate 
##        using the ingredients-based method

## b) two tables, all saved in the folder "./output/2_Tables":
##     1. "table3.csv": 
##        Table 3. Cost per child by ingredient, by month and by year
##     2. "table4A.csv": 
##        Table 4: Monthly and annual quantities and prices of ingredients
##        Panel A: State-level inputs for serving 5,135 children 
##                 in 48 municipalities.
##     3. "table4B.csv": 
##        Table 4: Monthly and annual quantities and prices of ingredients
##        Panel B: Municipal-level inputs for serving 2,888 children 
##                 in 32 sampled municipalities.

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 1. SET DIRECTORY AND LOAD PACKAGES
#----------------------------------------------------------------------------------------------------------------------------------------------------------
## Remove everything from the memory
rm (list = ls())

## Set up the directory
## Notes: Please change the directory for your computer 
##        when you replicate the analysis. 

## Load the packages
# to recover the environment uncomment the following lines only once, when first reading the project
renv::restore()
# and follow the instructions. 

### For data cleaning
# the packages are commented out as the renv is included in the package, but you 
# can uncomment these lines if you prefer to manually add the packages. 
# this might change reproducibility in the feature 


if (!require("dplyr", character.only = TRUE)) {
  install.packages("dplyr")
  library("dplyr", character.only = TRUE)
}

if (!require("tidyr", character.only = TRUE)) {
  install.packages("tidyr")
  library("tidyr", character.only = TRUE)
}

if (!require("readr", character.only = TRUE)) {
  install.packages("readr")
  library("readr", character.only = TRUE)
}

### For graphing

if (!require("ggplot2", character.only = TRUE)) {
  install.packages("ggplot2")
  library("ggplot2", character.only = TRUE)
}

if (!require("ggrepel", character.only = TRUE)) {
  install.packages("ggrepel")
  library("ggrepel", character.only = TRUE)
}

## Set the encoding to UTF-8, which supports a wide range of characters, including those used in the Portuguese language.
Sys.setlocale(category = "LC_ALL", locale = "Portuguese")

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 2. SET UP PARAMETERS
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Duration of PADIN implementation in months per year
PADIN_months <- 10

# Number of hours per working day
hours_per_working_day <- 8

# Number of children visited per ADI (home visitor)
Children_count_attended_per_ADI <- 10 *1.05

# PADIN scholarship for supervisors and ADIs
supervisor_PADIN_scholarship <- 600
ADIs_PADIN_scholarship <- 420

# fuel economy: Liters per 100 kilometer estimate in 2019
fuel_economy_car <- 7.5
## Source: Average fuel consumption of new LDVs 
## fell from 8.5 litres of gasoline equivalent per 100 kilometres (Lge/100 km) 
## in 2005 to reach 7.5 Lge/100 km in 2019, which is 5% above the global average. 
## https://www.iea.org/articles/fuel-economy-in-brazil

# The motorcycle corresponds to a 125c.c. Fan model
# Distance driven with 1 litre gasoline: 35 km in 2013/2014
fuel_economy_moterbike <- 100/35
# Source: https://notablesdelaciencia.conicet.gov.ar/bitstream/handle/11336/11735/CONICET_Digital_Nro.12978.pdf?sequence=1&isAllowed=y

# CPI in Brazil
CPI_2013 <- 119.4
CPI_2019 <- 167.4

# fuel price per liter in 2019
fuel_price <- 4.5
# According to data published by the National Agency for Petroleum, National Gas 
# and Biofuels in Brazil, the average consumer price of gasoline C in Ceara 
# is R$4.5 per liter in 2019.

# Number of liters of gas per motorbike per month
gas_per_motorbike_per_month <- (8 + 40)/2 # Reported by Capistrano

# Purchase cost of motorbike
cost_per_motorbike_per_month <- 5600 * CPI_2019 / CPI_2013/5/12
# The price of purchasing a motorcycle in 2013 is 5600 as reported in 
# https://notablesdelaciencia.conicet.gov.ar/bitstream/handle/11336/11735/CONICET_Digital_Nro.12978.pdf?sequence=1&isAllowed=y
# Also confirmed in https://www.pakwheels.com/forums/t/cg-125-fan-brazil/224400
# I adjusted the price to reflect the inflation.  
## An alternative plan of the motorbike rental price
# rental_cost_per_motorbike_per_month <- 600 # Reported by Mucambo

# Number of liters of gas per car per month
gas_per_car_per_month <- gas_per_motorbike_per_month * 
                         fuel_economy_car / 
                         fuel_economy_moterbike 

# Monthly cost of car
cost_per_car_per_month <- 36373/5/12
## The market price of Gol Bola was 36373 in total in 2019 
## and can be used for 5 years

# The number of municipalities participating in PADIN in 2018 
n_municipalities_2018 <- 48 # Two districts are considered two municipalities. 

# The number of supervisors working for PADIN among all municipalities
n_supervsiors_2018 <- 48 # two supervisors for Fore

# The number of ADIs working for PADIN among all municipalities
n_ADIs_2018 <- 489 # Confirmed by Benildes

# We decided not to use the number of families reported by the system, 
# due to its low data quality. Instead, we assume that each ADI serves 
# 10 families, among which 95% have one child at this age range and 
# 5% of the families have 2 children at this age range. 

# The number of children served by all municipalities in 2018
n_children_2018 <- n_ADIs_2018 * Children_count_attended_per_ADI 

# Exchange rate between Brazilian reals and USD in 2018
exchange_rate_2018 <- 3.65

# Define colors
colors <- c(
  # blue
  "#56B4E9", 
  # yellow
  "#E69F00", 
  # grey
  "#999999")

color_palette_blue <- c(
  # Six blue colors
  "#56B4E9",  # (Light to Medium Sky Blue)
  "#89CFF4", # Lighter Shade: (Light Sky Blue)
  "#278DC4",  # Darker Shade 1:  (Deep Sky Blue)
  "#1F73A2",  # Darker Shade 2:  (Medium Blue)
  "#16547A",  # Darker Shade 3:  (Dark Blue)
  "#0F3A54" # Darker Shade 4:  (Navy Blue)
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 3. RUN THE CODING FILES
#----------------------------------------------------------------------------------------------------------------------------------------------------------
source("./code/1_Brazil_PADIN_data_cleaning.R", encoding = "utf-8")
source("./code/2_Brazil_PADIN_variable_construction.R")
source("./code/3_Brazil_PADIN_analysis.R")
