#################################################################
### 			 Cost analysis of the PADIN program in Brazil				###
###              This R file cleans raw datasets              ###
###                 Created by: Yilin Pan                     ###
###	         	      Date: January 29, 2025                    ###
#################################################################

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 1. SURVEY DATA FROM SUPERVISORS
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Note: The R file only cleaned the variables used for the cost analysis. 

###### 1.1. Read in and clean the data

survey_data <- read.csv(
  "./data/1_De-identified/survey_data_de-identified.csv", fileEncoding = "ISO-8859-1")

## Paste the mismatched data to the right place for the first 8 municipalities
## Subset the chuck of data that are misplaced. 
mismatched_chuck <- survey_data %>%
  # Where this chuck of data are located in the dataset
  select(Houve.alguma.mudança.de.pessoal.no.último.mês.: 
           Como.o.repasse.do.recurso.foi.afetado.por.essas.mudanças.) %>%
  # For the first 8 municipalities
  slice(1:8)

### Place the chuck of data at the right place
survey_data[1:8, 
            # Where this chuck of data should be
            which(colnames(survey_data) == "O.supervisor.coordenador.recebe.seu.salário.de.mais.de.uma.fonte..PADIN.e.outra.fonte"):
            which(colnames(survey_data) == "NOTES.16")] <- mismatched_chuck

###### 1.2. Select the variables that will be directly used 
######      in the cost analysis and rename them. 
### 1.2.1 Supervisors
supervisor <- survey_data %>% rename(
  
  # What percentage of the supervisor's time is used in the work of PADIN?
  supervisor_pct_time = "Quantos.porcento.do.tempo.do.supervisor.é.utilizado.no.trabalho.do.PADIN..enter.percentage.",
  
  # What would be the work that the coordinator carries out outside the PADIN?
  supervisor_other_work = "Qual.seria.o.trabalho.que.o.coordenador.exerce.fora.do.PADIN.", 
  
  # What is the gross salary that the supervisor receives outside the PADIN scholarship (including benefits)?
  supervisor_gross_salary = "Qual.é.o.salario.bruto.que.o.supervisor.recebe.fora.a.bolsa.do.PADIN..incluindo.beneficios.",
  
  # What is the level of education of the coordinator/supervisor?
  supervisor_education = "Qual.é.o.nível.de.educação.do.coordenador.supervisor") %>%
  
  # Only select the variables related to supervisors. 
  select(municipality, supervisor_pct_time, supervisor_other_work, 
         supervisor_gross_salary, supervisor_education) %>%
  
  # change supervisor_pct_time and supervisor_gross_salary into numeric variables
  mutate(supervisor_pct_time = as.numeric(supervisor_pct_time), 
         supervisor_gross_salary = as.numeric(supervisor_gross_salary), 
         supervisor_education = recode(supervisor_education, 
           "Especialização" = "Post-graduate Specialization",
           "Graduação" = "Undergraduate Education", 
           "Graduação, Especialização" = "Post-graduate Specialization",
           "University" = "Undergraduate Education",
           "University, Certification" = "Undergraduate Education"))

## Impute the missing values or revise the outliers for 
## the self-reported gross salary

supervisor <- supervisor %>% mutate(supervisor_gross_salary = case_when(
    
    # "M3": The supervisor receives very small amount of 
    # compensation from the municipality
    municipality == "M3" ~ 1000, 
    
    # M30 should be 3108, rather than 3.10828
    municipality == "M30" ~ 3108,
    
    # Use M11 to impute M25 
    # (similar size, similar job, next to each other)
    municipality == "M25" ~ 
      supervisor$supervisor_gross_salary[supervisor$municipality == "M11"],
    
    # M2: salary based on her position is 1228. 
    municipality == "M2" ~ 1228,
    
    TRUE ~ supervisor_gross_salary))

### 1.2.2 ADIs (home visitors)
ADI <- survey_data %>% rename(
       # How many ADIs work on PADIN?
         ADI_count = Quantos.ADIs.trabalham.no.PADIN.,
       # Do ADIs receive any additional contributions 
       # from PADIN in addition to scholarships?
         ADI_additional_compensation_YN = "As.ADIs.recebem.alguma.contribuição.adicional.pelo.PADIN..além.das.bolsas.", 
       # What is the amount of this contribution paid to 
       # the additional ADIs of the grant?
         ADI_additional_compensation = 
         "Qual.é.o.valor.dessa.contribuição.paga.para.as.ADIs.adicional.da.bolsa.",
       # How many minutes do ADIs usually spend with families 
       # on the visit?
         ADI_minutes_per_visit  = "Quantos.minutos.os.ADIs.costumam.passar.com.as.famílias.na.visita.",
       # How many times a month are families visited?
         ADI_visits_frequency_per_month = "Quantas.vezes.por.mês.as.familías.são.visitadas.", 
       # What are the biggest challenges for maintaining the program?
         challenges = "Quais.são.os.maiores.desafios.para.a.manutenção.do.programa.") %>% 
      select (municipality, ADI_count, 
              ADI_additional_compensation_YN, 
              ADI_additional_compensation,
              ADI_minutes_per_visit, 
              ADI_visits_frequency_per_month, 
              challenges)

## Recode two errors in the variable 
## "How many minutes do ADIs usually spend with families on the visit?"
## The length of the visits was recorded in hours, rather than minutes. 
ADI <- ADI %>% mutate(ADI_minutes_per_visit = case_when(
                      municipality == "M15" ~ ADI_minutes_per_visit * 60, 
                      municipality == "M20" ~ ADI_minutes_per_visit * 60, 
                      TRUE ~ ADI_minutes_per_visit))

## Impute the missing values of the variable "ADI_visits_frequency_per_month" 
## using the designed frequency
ADI <- ADI %>% mutate(
       ADI_visits_frequency_per_month = case_when(
               ADI_visits_frequency_per_month == "" ~ "2 times per month",
               TRUE ~ ADI_visits_frequency_per_month)) %>% 
        mutate(ADI_visit_number_per_month = 
                 recode(ADI_visits_frequency_per_month,
                        "once a week" = 4,
                        "2 times per month" = 2)) 

## Impute the missing values of the variables 
## "ADI_additional_compensation_YN" and "ADI_additional_compensation"
ADI <- ADI %>% mutate(
  # If additional compensation is reported, 
  # impute the Yes/No question to "Yes"
         ADI_additional_compensation_YN = case_when(
               is.na(ADI_additional_compensation) == FALSE ~ "Yes", 
               TRUE ~ ADI_additional_compensation_YN)) 

# If additional compensation is not reported, code it as 0. 
ADI <- ADI %>% mutate(
  ADI_additional_compensation = 
    ifelse(is.na(ADI_additional_compensation) == TRUE, 0, 
           ADI_additional_compensation))

### 1.2.3 Transportation for home visits
transportation <- survey_data %>% rename(
      # How do they organize to go on visits?
      trans_together = "Como.eles.se.organizam.para.ir.nas.visitas.",
      
      # How do ADIs move to visits?
      trans_mode = "Como.as.ADIs.se.deslocam.para.as.visitas.", 
      
      # Notes
      trans_mode_notes = NOTES.5,
      
      # Do they get allowance?
      trans_ADI_allowance = "Eles.recebem.ajuda.de.custo.",
      
      # What is the cost aid amount?
      trans_ADI_cost_aid = Qual.o.valor.da.ajuda.de.custo.,
      
      # Notes for aid amount
      trans_ADI_cost_aid_notes = NOTES.6,
      
      # How much do you estimate the daily cost of ADIs 
      # with transportation for visits? 
      trans_daily_cost = "Quanto.você.estima.que.seja.o.custo.diário.das.ADIs.com.transporte.para.as.visitas.",
      
      # How many vehicles in the municipality are used by PADIN?
      trans_vehicle = "Quantos.veículos.do.município.são.usados.pelo.PADIN.", 
      
      # Can you describe these municipality vehicles 
      # that are used by PADIN?
      trans_vehicle_type = "Você.pode.descrever.esses.veículos.do.município.que.sao.utilizados.pelo.PADIN.",
      
      # What percent of the use of this vehicle is used by PADIN?
      trans_vehicle_pct = "Quantos.porcento.do.uso.desse.veículo.é.utilizado.pelo.PADIN.", 
      
      # Notes
      trans_vehicle_notes = NOTES.10, 
      
      # Which of these resources were purchased or 
      # used by PADIN (since the beginning of the program)? 
      ## Fuel
      trans_fuel = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Combustivel.", 
      
      ## Daily [Transportation, food, lodging]
      trans_daily_transportation_food_lodging = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Diarias..transporte..comida..hospedagem..", 
      
      ## Purchase of permanent equipment such as car, motorcyles, etc
      trans_purchase_cars_motorcycles = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Compra.de.equipamentos.permanentes.como.carro..motos.etc....", 
      
      ## Motorbikes
      trans_motorbikes = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Motos.", 
      
      ## Cars
      trans_cars = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Carros.",
      
      ## Omnibus
      trans_omnibus = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Onibus.") %>%
  
  # Select the variables
  select(municipality, trans_together, trans_mode, 
        trans_mode_notes, trans_ADI_allowance, trans_ADI_cost_aid, 
        trans_ADI_cost_aid_notes, trans_daily_cost, 
        trans_vehicle, trans_vehicle_type, trans_vehicle_pct, 
        trans_vehicle_notes, trans_fuel, 
        trans_daily_transportation_food_lodging,
        trans_purchase_cars_motorcycles, trans_motorbikes, 
        trans_cars, trans_omnibus)

# Recode the categorical variables by translating Portuguese into English
transportation <- transportation %>% 
  mutate(trans_together = recode(trans_together, 
    "Um ADI por distrito" = "One ADI per district", 
    "ADI's vão juntas por razões de segurança" = "ADIs go together for security reasons", 
    "ADI's vão juntas por questão de transporte" = "ADIs go together for transportation reasons"))

transportation <- transportation %>% 
  mutate(trans_mode = recode(trans_mode, 
    "Veiculo proprio sem ajuda de custo" = "Own vehicle free of charge",
    "Veiculo proprio e recebem ajuda de custo" = "Own vehicle and receive allowance",
    "More than one option" = "More than one option",
    "Veiculo do municipio" = "Municipal vehicle"))

# Impute missing values for transportation mode
transportation <- transportation %>% mutate(
  trans_mode = case_when(
  # For M2, the notes shows that some have their own rented motorbikes 
  # and others go on foot => "Own vehicle free of charge"
  municipality == "M2" ~ "Own vehicle free of charge",
  # For M32, the notes shows that ADIs move by foot => 
  # "Own vehicle free of charge"
  municipality == "M32" ~ "Own vehicle free of charge", 
  TRUE ~ trans_mode))

# Change the reported (percentage*100) to percentage
transportation <- transportation %>% 
  mutate(
  trans_vehicle_pct =  trans_vehicle_pct/100, 
  trans_vehicle_pct = case_when(
    # In the notes, M4 mentioned that PADIN uses 50% of the vehicle, 
    # but they didn't fill out the number in the variable "trans_vehicle_pct"
    municipality == "M4" ~ 0.5, 
    TRUE ~ trans_vehicle_pct))

# Notes: The transportation aids variable is recoded in 6.2. 

### 1.2.4 Training
training <- survey_data %>% rename(
  # How many times a year does the supervisor travel to events outside the county?
  supervisor_on_going_training_times = "Quantas.vezes.por.ano.o.supervisor.viaja.para.eventos.fora.do.município.", 
    
  # If nights are paid, what is the amount?
  supervisor_on_going_training_compensation = "Se.diárias.sao.pagas..qual.o.valor....leave.if.not.applicable.",
  
  # If there are out-of-town events for ADIs, how many days are there?
  ADI_on_going_training_days = "Se.existem.eventos.fora.do.município.para.as.ADIs..quanto.dias.são.",
  
  # How many events do ADIs attend per year?
  ADI_on_going_training_events = "De.quantos.eventos.as.ADIs.participam.por.ano.",
  
  # If ADIs receive daily rate, how much?
  ADI_on_going_training_compensation = "Se.as.ADIs.recebem.diarias..quanto..e.a.diaria...leave.blank.if.not.applicable.",
  
  # Notes for training
  ADI_on_going_training_notes = NOTES.12) %>% 
  select(municipality, supervisor_on_going_training_times, 
         supervisor_on_going_training_compensation, 
         ADI_on_going_training_days, ADI_on_going_training_events, 
         ADI_on_going_training_compensation, 
         ADI_on_going_training_notes)

# Recode the variable "How many times a year does the supervisor travel to 
# events outside the county?"
# If "Once a month" is reported, code it as the number of months PADIN lasts
training <- training %>% 
  mutate(supervisor_on_going_training_times = 
          ifelse(supervisor_on_going_training_times == "Once a month", 
                 PADIN_months * 1, supervisor_on_going_training_times)) %>% 
  mutate(supervisor_on_going_training_times = 
           as.numeric(supervisor_on_going_training_times))

# Recode the variable "ADI_on_going_training_days" for M3
# It is reported as 251. It should be 2
training <- training %>% 
  mutate(ADI_on_going_training_days = 
           ifelse(municipality == "M3", 2, 
                  ADI_on_going_training_days))

### 1.2.5 Community meetings
# How often are the meetings?
community_meetings <- survey_data %>% rename(
  # How often are the meetings?
  community_meetings_frequency = "Qual.a.frequência.das.reuniões.comunitarias.",
  # Is there a volunteer who devotes time to PADIN? 
  # This could include people cooking food, cleaning up, transporting food, etc.
  community_meeting_volunteer = "Existe.algum.voluntário.que.dedique.tempo.para.o.PADIN..This.could.include.people.cooking.food..cleaning.up..transporting.goods..etc...only.ask.if.the.checklist.item..services..was.checked.above..") %>%
  select(municipality, community_meetings_frequency, 
         community_meeting_volunteer) %>% 
  mutate(community_meetings_frequency = 
           as.factor(community_meetings_frequency)) %>% 
  mutate(community_meetings_number_per_year = 
           recode(community_meetings_frequency, 
                  "Once per month" = PADIN_months * 1,
                  "Twice per month" = PADIN_months * 2, 
                  "Once every other month" = PADIN_months / 2, 
                  
                  "Once every 6 months" = 2, 
                  # Notes from Kamila: They were one of the poorest cities I went. 
                  # They don't even have water in the bathrooms. 
                  # I believe the data is correct. 
                  # We rounded the number (10 months/6 months per meeting) up to 2. 
                  
                  "Once per week" = PADIN_months * 4, 
                  # Notes from Kamila: They held more community meetings 
                  # because in each week they held one community meeting in a district. 
                  
                  "Other" = PADIN_months)) 
                  # Notes from Kamila: They have no standards,
                  # but I put on notes that in the previous years 
                  # they had 10 community meetings. 
                  # This is also a reasonable assumption since PADIN 
                  # was 10 months a year.

### 1.2.6 Materials
materials <- survey_data %>% 
  rename(
  # Which of these resources were purchased or used by PADIN 
  # (since the beginning of the program)? 
  ## Educational materials for visits
  materials_for_visit = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Materiais.pedagogicos.para.visitas.", 
  
  ## Office supplies
  office_supplies = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Material.de.expediente.", 
  
  ## Materials for community visits
  materials_for_community_visits = "Quais.desses.recursos.foram.sao.comprados.ou.usados.pelo.PADIN..desde.o.inicio.do.programa....Materiais.para.visitas.comunitarias.") %>%
  
  select(municipality, materials_for_visit, office_supplies, 
         materials_for_community_visits)


### 1.3 Combine all the survey data together
survey_data_list <- list(supervisor, ADI, transportation, 
                         training, community_meetings, materials)    
survey_data <- Reduce(merge, survey_data_list)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 2. M&E data
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Load the de-identified data. The original was provided by the state government
monitoring_and_evaluation_data <- read.csv("./data/1_De-identified/monitoring_and_evaluation_data_de-identified.csv")

monitoring_and_evaluation_data <- monitoring_and_evaluation_data %>% 
            # Rename the variables
             rename(supervisor_count = "SUPERVISORES", # Number of supervisors
                    ADIs_count = "VISITADORES", # Number of ADIs
                    funding_formula = "BENEFICIçRIOS", # funding formula
                    total_cost = "RECURSO..R...MENSAL.BOLSAS") %>%
                         # Total cost from the municipality level
                    # Remove the last two rows as they are sums
                    slice(1:(n() - 2)) %>%
                    # Change the number of supervisors to numeric values
                    mutate(supervisor_count = as.numeric(supervisor_count))
  
#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 3. State-level budget
#----------------------------------------------------------------------------------------------------------------------------------------------------------

###### 3.1. Read in and clean the data

## Load the raw data
## Notes: The state-level budget for PADIN (2016-2018) was passed to us in the format 
##        of a pdf file. We transferred the items spent in 2018 and their cost into the 
##        Excel file, excluding the cost of the impact evaluation and the investment 
##        from the municipalities. When one resource was used for multiple years, we divided 
##        the cost of the resource by the number of years that it was used to get the annual cost. 

state_budget <- read.csv("./data/1_De-identified/state_budget_2018.csv")

state_budget <- state_budget %>% 
          # Remove the first column, i.e., the list of ingredients in Portuguese
            select(- Item_Portuguese) %>%
          # Remove the last row that is "tickets to Symposium"
            slice(1:(n() - 1))

# Number of supervisors, ADIs, families and children 
# in all municipalities served in 2018. 
n_municipalities_2018 <- 48 # Two districts are considered two municipalities. 
n_supervsiors_2018 <- 48 # two supervisors for Fore
n_ADIs_2018 <- 489 # Confirmed by Benildes

# We decided not to use the number of families reported by the system, 
# due to its low data quality. Instead, we assume that each ADI serves 
# 10 families, among which 95% have one child at this age range and 
# 5% of the families have 2 children at this age range. 
n_children_2018 <- n_ADIs_2018 * Children_count_attended_per_ADI 
# Benildes' estimate is that 95% of the families have one child at this age range,
# While 5% of the served families have 2 children at this age range. 


## Training
# Information from email exchanges with () Katiane Liberato <katiane.liberato@prof.ce.gov.br>  
# Regarding the costs of PADIN training logistics in the 2018/19 years:
# 2018 - BRL 96,738.00 was invested in the training of 486 professionals 
# (49 municipal supervisors, 412 Child Development Agents and 26 technicians from SEDUC/CREDEs). 
# It is worth noting that in this year R$76,500.00 was invested in the payment of scholarships 
# for the 9 trainers (professionals selected to provide training at the centers).

# Information from the financial manager of the PADIN coordinator
# 4 training meetings with 2 days each meeting.
# 486 professionals * 4 training courses * 2 days * R$46.00 = 178.848,00

# Out of the three numbers of the training, we adopted the last one.
training_total_s <- 178848

## Teacher kits
kits_total_s <- state_budget$Cost[4]/30 * n_municipalities_2018
# For distribution between municipalities, 30 kits were used (28 municipalities + 2 districts in the capital)
# We divided the total cost of pedagogical kits by 30 municipalities to get the cost per kit. Then multiply it by 48
# The 8 kits that are included in the logistics price were used in the training process

## PADIN scholarships
# Instead of using the PADIN scholarships reported in the financial spreadsheet, we calculated it by ourselves. 

## PADIN scholarship for supervisors and ADIs
supervisor_PADIN_scholarship <- 600
ADIs_PADIN_scholarship <- 420

supervisor_scholarships_s <- supervisor_PADIN_scholarship * PADIN_months * n_supervsiors_2018
ADI_scholarships_s <- ADIs_PADIN_scholarship * PADIN_months * n_ADIs_2018

## State personnel
personnel_total_s <- state_budget$Cost[6]

## Logistics => Food
food_total_s <- state_budget$Cost[3]

state_expense <- bind_cols(
  c("State personnel", "Training", "Teaching kits", 
    "Supervisors", "Home visitors", "Food"), 
  c(personnel_total_s, training_total_s, kits_total_s, 
    supervisor_scholarships_s, ADI_scholarships_s, food_total_s))

colnames(state_expense) <- c("Ingredient", "Cost")
  
#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 4. Municipal level budgets for food and office supplies
#----------------------------------------------------------------------------------------------------------------------------------------------------------
## Load the de-identified dataset
# Note. 20 municipalities submitted their monthly budgets on office supplies, 
#       food and some other items.
#       Kamila entered the numbers into the Excel file 
#       "PADIN budgets.xlsx" manually. 
#       Yilin transferred those monthly tables by category into 
#       a long dataset manually. 

municipality_budget <- read.csv(
  "./data/1_De-identified/municipality_budget_de-identified.csv")

# The Unit variable has some characters. 
# Remove those characters from the string and only keep the numbers
municipality_budget$unit <- lapply(municipality_budget$unit, 
                                   function(x) as.character(x))
municipality_budget$unit <- lapply(municipality_budget$unit, 
                                   function(x) readr::parse_number(x))

# Remove the R$ from the unit price variable and only keep the numbers
municipality_budget$unit.price <- lapply(municipality_budget$unit.price, 
                                         function(x) as.character(x))
municipality_budget$unit.price <- lapply(municipality_budget$unit.price, 
                                         function(x) readr::parse_number(x))

# Change those variables to numeric
municipality_budget$unit = as.numeric(unlist(municipality_budget$unit))
municipality_budget$unit.price = as.numeric(
                                 unlist(municipality_budget$unit.price))
municipality_budget$cost = as.numeric(unlist(municipality_budget$cost))

municipality_budget <- municipality_budget %>% 
  mutate(
 # The unit cost of TNT can be as low as R$1.1 and as high as R$93. 
 # When TNT's unit price is RS$93, I changed it to R$1.5.
  unit.price = case_when(
    item == "TNT" & unit.price == 93 ~ 1.5,
    TRUE ~ unit.price), 
  # Recalculate the total cost of TNT 
  # after replacing those unreasonably large prices
  cost = case_when(
    item == "TNT" ~ unit.price * unit,
    TRUE ~ cost)
  )

municipality_budget <- municipality_budget %>% 
  mutate(category = case_when(
                    category == "Vehicle Rental" ~ "Vehicle rental", 
                    category == "Vehicle Maintenance" ~ "Vehicle maintenance", 
                    TRUE ~ category))

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 5. GPS data
#----------------------------------------------------------------------------------------------------------------------------------------------------------
###### 5.1. Read in and clean the data

transportation_gps <- read.csv("./data/1_De-identified/transportation_gps_de-identified.csv") 

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 6. Cross-validation
#----------------------------------------------------------------------------------------------------------------------------------------------------------

# 6.1. Number of ADIs by municipality: Survey data vs. M&E data

# Select the variable "the number of ADIs" 
# from the M&E data and merge it to the survey data
survey_data <- left_join(survey_data, 
                        monitoring_and_evaluation_data %>% 
                          select(municipality, ADIs_count), 
                                 by = "municipality") %>% 
  # Rename the variable "the number of ADIs" by adding the data sources 
  rename(ADI_count_survey = ADI_count,
         ADI_count_MandE = ADIs_count) %>%
  # Calculate the difference between the two variables
  mutate(diff = ADI_count_survey - ADI_count_MandE) %>%
  # We used M&E data to replace the survey data when there are discrepancies
  mutate(ADI_count_validated = case_when(
    diff != 0 ~ ADI_count_MandE, 
    TRUE ~ ADI_count_survey)) %>%
  # Drop the ADI_count_MandE variable and the diff variable
  select(- c(ADI_count_MandE, diff))

# 6.2. ADIs' additional compensation and transportation aid

# Check ADI_additional_compensation, trans_ADI_cost_aid 
# and trans_ADI_cost_aid_notes to see whether they overlapped. 
ADI_compensation <- left_join(ADI %>% 
                              select(municipality, 
                                     ADI_additional_compensation_YN, 
                                     ADI_additional_compensation), 
                              transportation %>% 
                              select(municipality, 
                                     trans_ADI_cost_aid, 
                                     trans_ADI_cost_aid_notes), 
                              by = "municipality")

survey_data <- survey_data %>% 
  mutate(ADI_additional_compensation = case_when(
         municipality == "M11" ~ 517/2, 
        TRUE ~ as.numeric(ADI_additional_compensation)))

survey_data <- survey_data %>% 
  mutate(trans_ADI_cost_aid = case_when(
                      municipality == "M11" ~ 517/2, 
                      municipality == "M3" ~ trans_ADI_cost_aid/2,
                      TRUE ~ as.numeric(trans_ADI_cost_aid)), 
         trans_ADI_cost_aid_ADI_count = case_when(
                      municipality == "M5" ~ 3,
                      municipality == "M30" ~ 2,
                      TRUE ~ as.numeric(survey_data$ADI_count_validated)))

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 7. Export the clean datasets
#----------------------------------------------------------------------------------------------------------------------------------------------------------
write.csv(survey_data, 
          "./data/3_Cleaned/survey_data_cleaned.csv", row.names = FALSE)
write.csv(monitoring_and_evaluation_data, 
          "./data/3_Cleaned/monitoring_and_evaluation_data_cleaned.csv", 
          row.names = FALSE)
write.csv(state_expense, 
          "./data/3_Cleaned/state_budget_cleaned.csv", 
          row.names = FALSE)
write.csv(municipality_budget, 
          "./data/3_Cleaned/municipality_budget_cleaned.csv",
          row.names = FALSE)
write.csv(transportation_gps, 
          "./data/3_Cleaned/transportation_gps_cleaned.csv",
          row.names = FALSE)
