#################################################################
### 			 Cost analysis of the PADIN program in Brazil				###
###   This R file constructs new variables and analyzes data  ###
###                 Created by: Yilin Pan                     ###
###	         	      Date: January 17, 2024	  	              ###
#################################################################

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 0. READ IN DATASETS
#----------------------------------------------------------------------------------------------------------------------------------------------------------

## Read in the cleaned datasets
survey_data <- read.csv("./data/3_Cleaned/survey_data_cleaned.csv")
monitoring_and_evaluation_data <- read.csv("./data/3_Cleaned/monitoring_and_evaluation_data_cleaned.csv")
state_budget <- read.csv("./data/3_Cleaned/state_budget_cleaned.csv")
municipality_budget <- read.csv("./data/3_Cleaned/municipality_budget_cleaned.csv")
transportation_gps <- read.csv("./data/3_Cleaned/transportation_gps_cleaned.csv")

## Notes
## Labels: _m : Cost borne by the municipalities
##         _s : Cost borne by the state
##         _c : Cost borne by the communities, e.g., parents and volunteers
##         _q : quantities
##         _p : prices
## Parameters

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 1. SURVEY DATA
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# 1.1. Cost of supervisor's time per child per month

## Create the variable to show the number of children served in each municipality
survey_data <- survey_data %>% 
  mutate(children_count_served = 
         ADI_count_validated * Children_count_attended_per_ADI)

## Cost of supervisor's time borne by the municipality 
## per child per month
survey_data <- survey_data %>% 
    mutate(
    supervisor_cost_m = 
    supervisor_gross_salary * supervisor_pct_time/ 100 / children_count_served)

# 1.2. Cost of ADIs' time per child per month
## ADI's additional compensation in addition to the scholarship 
## (420 per person per month)
## The amount of additional compensation reported was paid to each ADI. 
survey_data <- survey_data %>% 
  mutate(adi_cost_m = 
           ADI_additional_compensation / Children_count_attended_per_ADI)

## How much time do ADI spent on visiting the families?
survey_data <- survey_data %>% 
  mutate(ADI_visits_minites_per_family_per_month = 
         ADI_minutes_per_visit * ADI_visit_number_per_month)

# 1.3. Transportation for home visits

survey_data <- survey_data %>% 
  mutate(
  ## Total cost of transportation per month
  trans_cost_total_m = case_when(
    
  trans_mode == "Own vehicle free of charge" ~ 0,
  trans_mode == "Own vehicle and receive allowance" ~ 
    as.numeric(trans_ADI_cost_aid * trans_ADI_cost_aid_ADI_count),

   # 1) For M16, 4 ADIs travel in their own vehicle with aid 
   #    between 8 and 40 liters per month depending on the distance. 
   #    4 ADIs travel using public transportation. => 
  #     Assuming no transportation aids. 
  municipality == "M16" ~  (8 + 40)/2 * fuel_price * 4,
  # Note that the fuel cost is 408 per month based on the survey.  
  # In the municipality budget, the fuel cost for M16 is 655 per month.
  
  # 2) For M25, 4 ADIs travel by motorbike from the secretariat and 
  #    4 ADIs on foot. 
  municipality == "M25" ~ (gas_per_motorbike_per_month * fuel_price + 
                                 cost_per_motorbike_per_month) * 4,
  # In the municipality budget, the fuel cost for M25 is 
  # 1055.25 per month in total. 
  # Motorbike rental cost was not reported in the municipality budget. 
  
  # 3) For M10, ADIs travel on foot and on their own motorbike. 
  #    => No compensation
  municipality == "M10" ~ 0,
  # In municipality budget, there is no fuel cost or vehicle cost. 
  
  # 4) For M6, ADIs travel in municipal vehicles. 
  # There are 5 vehicles (3 fiat uno / siena / gol), and 
  # 35% of the time was used by PADIN. 
  municipality == "M6" ~ (cost_per_car_per_month + 
                  gas_per_car_per_month * fuel_price) * 5 * trans_vehicle_pct,

  # 5) For M18, vehicle was rented by the municipality. 
  #    There was 1 Gol bola fully dedicated to PADIN. 
  municipality == "M18" ~ cost_per_car_per_month + 
                               gas_per_car_per_month * fuel_price,
  # In the municipality budget, the fuel is 100 per month, 
  # and the vehicle rental is 4973 per month

  # 6) For M22, 4 motos / corsa classic, 80% were used by PADIN. 
  #    The rent of 600.00 for each motorcycle plus gasoline
  municipality == "M22" ~ 
    (gas_per_motorbike_per_month * fuel_price + 
    cost_per_motorbike_per_month) * 4 * trans_vehicle_pct + 
    (cost_per_car_per_month + gas_per_car_per_month * fuel_price) * 
    trans_vehicle_pct, 
  
  # 7) For M26, 10 liters of gas per month for one / 
  #   03 do not use transport, they go on foot / 
  #   04 use a motorcycle and a car rented from education secretariate./ 
  #   They use 50% of these transports.
  municipality == "M26" ~ 10 * fuel_price * 1 + 
    (cost_per_car_per_month + gas_per_car_per_month * fuel_price) * 
    trans_vehicle_pct + 
    (gas_per_motorbike_per_month * fuel_price + cost_per_motorbike_per_month) * 
    trans_vehicle_pct, 
  # In the municipality budget, the fuel is 732 per month in total, 
  # and the vehicle rental is 2000. 
  
  # 8) For M17, refuel at the fuel station on the municipal bill
  municipality == "M17" ~ 0))

# M7 reported that ADIs use their own vehicle free of charge, 
# but there is R$400 of fuel cost per month in the municipality budget.  
# M4 reported that ADIs use their own vehicle free of charge, 
# but there is R$600 of fuel cost, R$3500 of vehicle rental cost, 
# and $35000 of vehicle maintenance cost in the municipality budget. 
# M2 reported that ADIs use their own vehicle free of charge, 
# but there is R$25333 of transportation cost in the municipality budget. 
# M11 reported that ADIS use their own vehicle 
# and receive allowance of R$517. In the municipality budget, 
# there is a transportation cost of 5406 per month. 
# M20 reported that ADIs use their own vehicle free of charge, 
# but there is R$105 of fuel cost in the municipality budget. 

## Don't know why "M4" and "M17" are coded as NA, so I coded them manually. 
survey_data$trans_cost_total_m[survey_data$municipality == "M4"] <- 
  10 * fuel_price * 1 + 
  (cost_per_car_per_month + gas_per_car_per_month * fuel_price) * 
  survey_data$trans_vehicle_pct[survey_data$municipality == "M4"] + 
  (gas_per_motorbike_per_month * fuel_price + cost_per_motorbike_per_month) * 
  survey_data$trans_vehicle_pct[survey_data$municipality == "M4"]

survey_data$trans_cost_total_m[survey_data$municipality == "M17"] <- 0

## Create the variable to estimate the transportation cost per month per child
survey_data <- survey_data %>% 
  mutate(trans_cost_m = trans_cost_total_m/children_count_served)

# 1.4.1 Supervisor's training
# Number of days for initial training 
# (5 day, 40 hours, in total, amortized over 5 years)
supervisor_initial_training_days <- 5/5

# Number of days per on-going training
supervisor_on_going_training_days_per_training <- 1

survey_data <- survey_data %>% 
  mutate(supervisor_training_cost_total_m = 
                (supervisor_initial_training_days + 
                supervisor_on_going_training_days_per_training * 
                supervisor_on_going_training_times) * 
                supervisor_on_going_training_compensation / PADIN_months, 
         supervisor_training_cost_m = supervisor_training_cost_total_m / 
                 children_count_served)

# 1.4.2 ADIs training

# Number of days for initial training (5 days in total, amortized over 2 years given the high turn-over rate)
ADI_initial_training_days <- 5/2

survey_data <- survey_data %>% 
  mutate(ADI_training_cost_total_m = 
               (ADI_initial_training_days + 
               # Out-of-town training days. 
                ADI_on_going_training_days) * 
                ADI_on_going_training_compensation / PADIN_months, 
        ADI_training_cost_m = ADI_training_cost_total_m / 
                              children_count_served)
# Notes. Based on the notes for ADIs training, 
#        it makes sense to assume that the out-of-town training days
#        are totals, rather than days per event.

# 1.5.Community meetings

# 1.5.1. Parents' opportunity cost to attend the community meetings
## Number of hours spent by parents to attend one session: 
## 3 hours for the session
community_meetings_hours_per_session <- 3

## Assume one caregiver from one family participated in each meeting, 
## and the participation rate of the community meetings is 80% - 95%. 
caregiver_per_child_served <- 1 * 0.9

# Minimum wage per hour
min_wage_per_hour <- 4.53

survey_data <- survey_data %>% 
  mutate(
     community_meetings_participants_count = 
       caregiver_per_child_served * children_count_served, 
     community_meetings_total_cost_c = 
       community_meetings_number_per_year / PADIN_months * 
       community_meetings_hours_per_session * 
       community_meetings_participants_count * min_wage_per_hour, 
     community_meetings_avg_cost_c = community_meetings_total_cost_c / 
       children_count_served)

# 1.5.2. Volunteers' opportunity cost
# Assume that when a municipality reports yes to the question 
# "Is there a volunteer who devotes time to PADIN?",
# half of the meetings had 1 volunteer.  

## Number of volunteers to help a session
volunteer_count_per_community_meeting <- 1

## % of community meetings that volunteers help with
community_meetings_pct_with_volunteers <- 0.5

## Hours spent by volunteers to help with one community meeting
volunteer_hours_per_session <- 4 
# 4 hours for organizing the space, prepare and distribute food.  

survey_data <- survey_data %>% 
  mutate(
  volunteer_total_cost_c = ifelse(community_meeting_volunteer == "yes", 
  # For the community meetings, 
  # an ADI would organize one for all of her 10 families. 
      community_meetings_number_per_year * ADI_count_validated / 
      PADIN_months * community_meetings_pct_with_volunteers * 
      volunteer_count_per_community_meeting * 
      volunteer_hours_per_session, 0), 
  volunteer_cost_c = volunteer_total_cost_c /children_count_served)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 2.M&E data and 3. State-level budget
#----------------------------------------------------------------------------------------------------------------------------------------------------------

## The state budget for 2018 includes training, materials, 
## food, PADIN scholarships and state-level personnel cost.
## We divided the total budget by the number of children served 
## in all 48 municipalities, not only the 32 municipalities in the survey sample. 

# Estimate the cost per month per child
cost_data_s <- state_budget %>% 
  mutate(`Cost per child per month` = Cost/PADIN_months/n_children_2018, 
         `Funding agency` = "State") %>%
  select(Ingredient, `Cost per child per month`, `Funding agency`)

# Cost per month per child borne by the state
operation_cost_s <- sum(cost_data_s$`Cost per child per month`)

# Create the quantity and price dataset for state budget

# State budget: Select the variables related to quantities
ingr_q_s <- c(
  # State personnel dedicated to the 48 municipalities per month
  # According to the state budget, there are 24 personnel 
  # working for 48 municipalities, including
  # SEDUC: 5 people GT PADIN (salary), 1 coordination (salary and bonus),
  # 1 Consultant, 1 IT technician
  # CREDE – 16 people (salary and bonus)
  24,
  
  # Number of supervisors
  n_supervsiors_2018 <- 48,
  
  # Number of ADIs
  n_ADIs_2018, 
  
  # Number of training sessions dedicated to 
  # children in the 48 municipalities:
  # 486 professionals were trained across the 48 municipalities in the state
  # 4 training courses
  # 2 days
  486 * 4 * 2,
  
  # Number of teaching kits, one kit per municipality
  n_municipalities_2018,
  
  # Number of children for food
  n_children_2018
)

ingr_p_s <- c(
  # Average month salary per state personnel 
  state_budget$Cost[state_budget$Ingredient == "State personnel"]/24/PADIN_months,
  
  # Supervisor's scholarship per person per month
  supervisor_PADIN_scholarship,
  
  # ADIs' scholarship per person per month
  ADIs_PADIN_scholarship,
  
  # training cost per person per course
  46.00/PADIN_months,
  
  # Price of teaching kit
  state_budget$Cost[state_budget$Ingredient == "Teaching kits"]/n_municipalities_2018/PADIN_months,
  
  # Food per child per month
  state_budget$Cost[state_budget$Ingredient == "Food"]/PADIN_months/n_children_2018
)

ingr_state <- data.frame(
  rep("State", 6), 
  c("State personnel", 
    "Supervisors",
    "Home visitors",
    "Training",
    "Teaching kits",
    "Food"), 
  ingr_q_s, 
  c("FTE", "FTE", "FTE", "Person*course*day", "Kit", "Beneficiary"), 
  ingr_p_s, 
  ingr_q_s * ingr_p_s, 
  ingr_q_s * ingr_p_s/n_children_2018)

colnames(ingr_state) <- c("Funder", "Ingredient", "Quantity", 
                          "Unit", "Price", 
                          "Total cost per month", "Cost per child per month")

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 4. Municipal-level expenditure on food and office supplies
#----------------------------------------------------------------------------------------------------------------------------------------------------------
municipality_budget_summary <- municipality_budget %>% 
  group_by(municipality, month, category) %>% 
  summarize(sum = sum(cost)) %>% ungroup %>% 
  group_by(municipality, category) %>%
  summarize(cost = mean(sum, na.rm = TRUE))

municipality_budget_food <- municipality_budget_summary %>% 
                            filter(category == "Food")

municipality_budget_office_supplies <- municipality_budget_summary %>% 
                                       filter(category == "Office supplies")

food_m <- left_join(survey_data %>% 
                      select(municipality, children_count_served), 
                    municipality_budget_food %>% 
                      select(municipality, cost), 
                    by = "municipality") %>% 
          rename("food_total_cost_m" = "cost") %>% 
          mutate( 
             food_avg_cost_m = food_total_cost_m / children_count_served, 
             # Impute the missing values using the mean of the observed values
            food_avg_cost_m = ifelse(
              is.na(food_avg_cost_m) == TRUE, 
              mean(food_avg_cost_m, na.rm = TRUE), food_avg_cost_m))

office_supplies_m <- left_join(survey_data %>% 
                                 select(municipality, children_count_served), 
                               municipality_budget_office_supplies %>% 
                                 select(municipality, cost), 
                              by = "municipality") %>% 
                     rename("office_supplies_total_cost_m" = "cost") %>% 
                     mutate(
                        office_supplies_avg_cost_m = 
                          office_supplies_total_cost_m / children_count_served, 
                    # Impute the missing values using 
                    # the mean of the observed values
                        office_supplies_avg_cost_m = 
                          ifelse(is.na(office_supplies_avg_cost_m) == TRUE, 
                                 mean(office_supplies_avg_cost_m, na.rm = TRUE), 
                                 office_supplies_avg_cost_m))

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 5. GPS data
#----------------------------------------------------------------------------------------------------------------------------------------------------------

########## 5.1. Analyze the transportation pattern by neighborhood data

## Since the average duration of a family visit takes about one hour, 
## we assume that an ADI would be able to visit 4 households a day at most 
## if they are in the same neighborhood.
max_households_per_day <- 4

# index_visitor is the unique ID for ADI by neighborhood
ADI_neighborhood <- transportation_gps %>% 
  group_by(municipality, index_visitor, visitor_id) %>% 
  summarize(
  # Number of families each ADI is responsible for in a specific neighborhood
  n_households = n(), 
  # Average distance of those families
  average_distance = mean(distance),
  # Average travelling time
  avg_travel_time = mean(duration)) %>%
  mutate(trans_mode = case_when(average_distance < 2 ~ "Walking", 
      average_distance >= 2 & average_distance < 10 ~ "Motorbiking", 
                 average_distance >= 10 ~ "Driving with traffic")) %>% 
  ungroup() %>%
  mutate(number_of_trips = ceiling(n_households/max_households_per_day)) 

# Number of households to visit per trip per ADI from the neighborhood data
average_households_per_trip_per_ADI <- ADI_neighborhood %>% 
  group_by(municipality, visitor_id, trans_mode) %>% 
  summarize(
    n_households = sum(n_households), 
    n_trips = sum(number_of_trips), 
    n_households_per_trip = n_households / n_trips) %>% 
  ungroup %>%
  group_by(municipality, trans_mode) %>% 
  summarize(
    n_households_per_trip_average = mean(n_households_per_trip))

transportation_distribution <- ADI_neighborhood %>% 
  group_by(municipality, trans_mode) %>% 
  summarize(
  # total number of households by transportation mode and municipality
    n_households = sum(n_households),
    average_distance = mean(average_distance), 
    avg_travel_time = mean(avg_travel_time)
    ) %>% 
  ungroup %>% 
  group_by(municipality) %>% 
  mutate(
  # percentage of households by transportation mode and municipality
  pct_households = n_households/sum(n_households)) %>%
  left_join(y = survey_data %>% 
              select(municipality, ADI_minutes_per_visit, 
                     ADI_visit_number_per_month,
                     children_count_served), 
            by = "municipality") %>% 
  left_join(y = average_households_per_trip_per_ADI, 
            by = c("municipality", "trans_mode")) %>%
  mutate(
    n_households_imputed =  pct_households * children_count_served, 
    number_of_trips = ceiling(n_households_imputed/
                                n_households_per_trip_average)) %>%
  select(- children_count_served)

# Assume that ADIs all use motorbikes rent by the municipality
# Assume that if an ADI needs to use a motorbike to visit an neighborhood, 
# he/she is not going to share a motorbike with other ADIs on that day. 
n_motorbikes <- transportation_distribution %>% 
                filter(trans_mode == "Motorbiking") %>%
                mutate(
                # Time for ADIs to use motorbikes
                   motor_time = 
                   # Time spent for family visit
                   (n_households_imputed * ADI_minutes_per_visit + 
                   # Travelling time
                   avg_travel_time * 2 * number_of_trips) * 
                   ADI_visit_number_per_month) %>%
                summarize(motor_days = 
                            ceiling(motor_time/60/hours_per_working_day)) %>%
                group_by(municipality) %>% 
                summarize(
                  motor_days_sum = sum(motor_days), 
                 # Assume one motorbike can be used for 15 days per month. 
                 # This is a conservative estimate so that we leave out 
                 # some space for ADIs to coordinate the schedule. 
                  n_motorbikes = ceiling(motor_days_sum/15))

n_cars <- transportation_distribution %>% 
  filter(trans_mode == "Driving with traffic") %>%
  mutate(
    # Time for an ADI to use a car for a neighborhood
    car_time = 
      # Time spent for family visit
      (n_households_imputed * ADI_minutes_per_visit + 
         # Travelling time
         avg_travel_time * 2 * number_of_trips) * 
      ADI_visit_number_per_month) %>%
  summarize(car_days = ceiling(car_time/60/hours_per_working_day)) %>%
  group_by(municipality) %>% 
  summarize(
    car_days_sum = sum(car_days), 
    # Assume one car can be used for 15 days per month. 
    # This is a conservative estimate so that we leave out some space 
    # for ADIs to coordinate the schedule. 
    # Assume two ADIs can share a car. 
    n_cars = ceiling(car_days_sum/2/15))

## => Assume everyone starts from the municipality administrative building 
## => Car sharing: We assume two ADIs can share a car.
trans_gps_cost <- transportation_distribution %>%
  mutate( # Estimate the fuel cost for each type of transportation mode
  fuel_cost = case_when(trans_mode == "Driving with traffic" ~ 
                        # Round trip
                          average_distance * 2 * 
                        # Number of trips needed for all households with driving
                          number_of_trips * 
                        # Number of visits per month
                          ADI_visit_number_per_month/
                        # Transfer to liter of gas
                          100 * fuel_economy_car * fuel_price, 
                       trans_mode == "Motorbiking" ~ 
                         average_distance * 2 * number_of_trips * 
                         ADI_visit_number_per_month / 100 * 
                         fuel_economy_moterbike * fuel_price,
                       trans_mode == "Walking" ~ 0)) %>% 
  group_by(municipality) %>% 
  summarize(
      fuel_cost = sum(fuel_cost, na.rm = TRUE)) %>%
  left_join(y = n_motorbikes, by = "municipality") %>%
  left_join(y = n_cars, by = "municipality") %>%
  left_join(y = survey_data %>% 
              select(municipality, children_count_served), 
            by = "municipality") %>%
  mutate(motorbike_cost = n_motorbikes * cost_per_motorbike_per_month, 
         car_cost = n_cars * cost_per_car_per_month) %>%
  mutate(
    trans_total_cost_m = rowSums(select(., fuel_cost, motorbike_cost, 
                                        car_cost), na.rm = TRUE), 
    trans_avg_cost_m = trans_total_cost_m / children_count_served)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 6. Compile the quantities and prices matrix at the municipality level
### Quantities and prices for children served by all 32 municipalities
#----------------------------------------------------------------------------------------------------------------------------------------------------------

# Quantities of ingredients borne by the municipalities
ingr_q_m <- survey_data %>% 
  mutate(
    # Supervisors' time devoted to PADIN
    supervisor_pct_time = supervisor_pct_time/100, 
  
    # Supervisors' training days per month
    supervisor_training_days = 
       (supervisor_initial_training_days + 
       supervisor_on_going_training_days_per_training * 
       supervisor_on_going_training_times) / PADIN_months, 
  
    # ADIs' training days per month
    ADI_training_days = (ADI_initial_training_days + 
                        ADI_on_going_training_days)/ PADIN_months) %>%
  select(
    # Municipality name
    municipality,
    # Supervisor's time devotion
    supervisor_pct_time, 
    # Number of ADIs
    ADI_count_validated,
    # Supervisors' training days per month
    supervisor_training_days,
    # ADIs' training days per month
    ADI_training_days) %>%
  left_join(
    # Food
    food_m %>% select(municipality, children_count_served), 
    by = "municipality") %>% 
  left_join(
    # Office supplies
    office_supplies_m %>% select(municipality, children_count_served),
    by = "municipality") %>%
  left_join(
    # Number of motorbikes
    n_motorbikes %>% select(municipality, n_motorbikes),
    by = "municipality") %>%
  left_join(
    # Number of cars
    n_cars %>% select(municipality, n_cars),
    by = "municipality") %>%
  left_join(
    # Number of fuel in liters
    transportation_distribution %>%
      mutate( # Estimate the millage for each type of transportation mode
        fuel_liter = case_when(trans_mode == "Driving with traffic" ~ 
                              # Round trip
                               average_distance * 2 * 
                              # Number of trips needed for all households with driving
                                number_of_trips * 
                              # Number of visits per month
                                ADI_visit_number_per_month/
                              # Transfer to liter of gas
                                100 * fuel_economy_car, 
                               trans_mode == "Motorbiking" ~ 
                                average_distance * 2 * 
                                number_of_trips * 
                                ADI_visit_number_per_month/ 100 * 
                                fuel_economy_moterbike,
                               trans_mode == "Walking" ~ 0)) %>% 
      group_by(municipality) %>% 
      summarize(fuel_liter = sum(fuel_liter)), by = "municipality")

# Sum the quantities across municipalities
ingr_q_m_summary <- ingr_q_m %>% select(- municipality) %>% 
  summarize_all(sum, na.rm = TRUE)

# Create the weights to adjust prices based on the quantities
## Create a temporary 32*4 matrix that repeats the row sums by row  
ingr_q_m_summary_temp <- data.frame(matrix(
                                     unlist(rep(ingr_q_m_summary, 
                                            times = nrow(survey_data))),
                                           nrow = nrow(survey_data), 
                                           ncol = ncol(ingr_q_m_summary), 
                                           byrow = TRUE))

## The weights is equivalent to the quantities of each municipality divided
## by the sum of quantities across all municipalities. 
ingr_weights_m <- ingr_q_m %>% select(-municipality) / 
                  ingr_q_m_summary_temp

# Municipality: Select the variables related to prices
ingr_p_m <- survey_data %>% 
  select(municipality,
         # Supervisor's gross salary
         supervisor_gross_salary, 
         # additional compensation for ADI
         ADI_additional_compensation, 
         # supervisor's ongoing training
         supervisor_on_going_training_compensation, 
         # ADIs ongoing training compensation
         ADI_on_going_training_compensation)%>%
  left_join(
    # Food
    food_m %>% select(municipality, food_avg_cost_m), 
    by = "municipality") %>% 
  left_join(
    # Office supplies
    office_supplies_m %>% select(municipality, office_supplies_avg_cost_m),
    by = "municipality") %>%
  mutate(
    # prices of motorbikes
    cost_per_motorbike_per_month = cost_per_motorbike_per_month, 
    cost_per_car_per_month = cost_per_car_per_month, 
    fuel_price_per_liter = fuel_price)

ingr_p_m_summary <- data.frame(ingr_p_m %>% 
                                 select(- municipality) * 
                                 ingr_weights_m) %>% 
                    summarize_all(sum, na.rm = TRUE)

ingr_municipality <- data.frame(
  rep("Municipalities", 9), 
  c("Supervisors",
    "Home visitors",
    "Supervisors' training days",
    "Home visitors' training days",
    "Food", 
    "Office supplies",
    "Motorbikes",
    "Cars",
    "Fuel"), 
  unlist(unname(ingr_q_m_summary)), 
  c("FTE", "FTE", "Day", "Day", "Beneficiary", "Beneficiary", 
    "Motorbike", "Car", "Liter"), 
  unlist(unname(ingr_p_m_summary)), 
  unlist(unname(ingr_q_m_summary)) * unlist(unname(ingr_p_m_summary)), 
  unlist(unname(ingr_q_m_summary)) * unlist(unname(ingr_p_m_summary))/
    sum(survey_data$children_count_served))

colnames(ingr_municipality) <- c("Funder", "Ingredient", "Quantity", 
                                 "Unit", "Price", 
                                 "Total cost per month", 
                                 "Cost per child per month")

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 7. Compile the cost matrix
#----------------------------------------------------------------------------------------------------------------------------------------------------------

# Create the cost dataset for the municipality level cost
cost_data_m <- survey_data %>% 
  select(
      municipality, supervisor_cost_m, adi_cost_m, 
      # Self-reported transportation cost
      trans_cost_m, 
      supervisor_training_cost_m, 
      ADI_training_cost_m, 
      volunteer_cost_c, 
      children_count_served) %>% 
  left_join(y = food_m %>% select(municipality, food_avg_cost_m), 
            by = "municipality") %>%
  left_join(y = office_supplies_m %>% 
              select(municipality, office_supplies_avg_cost_m), 
            by = "municipality") %>%
  left_join(y = trans_gps_cost %>% 
              select(municipality, trans_avg_cost_m), 
            by = "municipality") %>%
  rename(trans_cost_m_survey = trans_cost_m, 
         trans_cost_m_gps = trans_avg_cost_m) %>%
  mutate(training_cost_m = rowSums(select(., supervisor_training_cost_m, 
                                          ADI_training_cost_m), na.rm = TRUE ), 
         # Community cost is the opportunity cost of the volunteers
         community_cost_c = volunteer_cost_c) %>%
  mutate(municipality_survey = rowSums(select(., supervisor_cost_m, adi_cost_m,  
                                     training_cost_m, trans_cost_m_survey, 
                                     food_avg_cost_m, 
                                     office_supplies_avg_cost_m), 
                                     na.rm = TRUE),
         municipality_gps = rowSums(select(., supervisor_cost_m, adi_cost_m,  
                                   training_cost_m, trans_cost_m_gps, 
                                   food_avg_cost_m, 
                                   office_supplies_avg_cost_m), 
                                   na.rm = TRUE))

# Add the state level cost to the municipal cost
cost_data <- cost_data_m %>% mutate(operation_cost_s = operation_cost_s)

cost_data <- cost_data %>% mutate(
  total_m_s_survey = rowSums(select(., municipality_survey, operation_cost_s), 
                             na.rm = TRUE),
  total_m_s = rowSums(select(., municipality_gps, operation_cost_s), 
                      na.rm = TRUE))

# Estimate the weighted average of all municipalities
cost_data_m_average <- cost_data_m %>% 
  mutate(children_served_pct = children_count_served/
           sum(children_count_served)) %>% 
  summarize(
      Supervisors = sum(supervisor_cost_m * children_served_pct), 
      `Home visitors` = sum(adi_cost_m * children_served_pct), 
      Training = sum(training_cost_m * children_served_pct), 
      Supplies = sum(office_supplies_avg_cost_m * children_served_pct), 
      Transportation = sum(trans_cost_m_gps * children_served_pct),
      Food = sum(food_avg_cost_m * children_served_pct), 
      Volunteers = sum(community_cost_c * children_served_pct)) %>% 
  t(.) 

cost_data_m_average <- as.data.frame(cost_data_m_average) %>% 
  rename(`Cost per child per month` = 1) %>% 
  tibble::rownames_to_column("Ingredient") %>% 
  mutate(`Funding agency` = "Municipality") %>%
  mutate(`Funding agency` = 
           case_when(Ingredient == "Volunteers" ~ "Community", 
                     TRUE ~ `Funding agency`))

# Combine the state level cost with the weighted average municipal cost
cost_data_state_municipality <- cost_data_s %>%
  bind_rows(cost_data_m_average)

write.csv(survey_data, 
          "./data/3_Cleaned/survey_data_constructed.csv",
          row.names = FALSE)
write.csv(cost_data, 
          "./data/3_Cleaned/cost_data_constructed.csv",
          row.names = FALSE)
write.csv(cost_data_state_municipality, 
          "./data/3_Cleaned/cost_data_state_municipality_constructed.csv",
          row.names = FALSE)
write.csv(ingr_state, 
          "./data/3_Cleaned/ingr_state_constructed.csv",
          row.names = FALSE)
write.csv(ingr_municipality, 
          "./data/3_Cleaned/ingr_municipality_constructed.csv",
          row.names = FALSE)
