#################################################################
### 			 Cost analysis of the PADIN program in Brazil				###
###           This R file generates tables and figures        ###
###                 Created by: Yilin Pan                     ###
###	         	      Date: January 29, 2025	  	              ###
#################################################################

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 0. READ IN DATASETS
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# The survey data
survey_data <- read.csv("./data/3_Cleaned/survey_data_constructed.csv")

# Municipal level cost data
cost_data <- read.csv("./data/3_Cleaned/cost_data_constructed.csv")
# Remove dots in column names
names(cost_data) <- gsub("\\.", " ", names(cost_data))

# Decomposition of cost by ingredient
cost_data_state_municipality <- 
  read.csv("./data/3_Cleaned/cost_data_state_municipality_constructed.csv")
names(cost_data_state_municipality) <- gsub("\\.", " ", 
                                            names(cost_data_state_municipality))

# Data from the online monitoring system
online_monitoring <- 
  read.csv("./data/1_De-identified/online_monitoring_de-identified.csv")

# Data from the original state budget
state_budget_original <- 
  read.csv("./data/1_De-identified/state_budget_2018.csv")

# Data from the municipality budget
municipality_budget <- 
  read.csv("./data/3_Cleaned/municipality_budget_cleaned.csv")

# Municipality statistics
#municipality_statistics <- 
 # read.csv("./data/1_De-identified/municipality_statistics_de-identified.csv")

# Ingredient data
ingr_state <- read.csv("./data/3_Cleaned/ingr_state_constructed.csv")
ingr_municipality <- 
  read.csv("./data/3_Cleaned/ingr_municipality_constructed.csv")
# Remove dots in column names
names(ingr_state) <- gsub("\\.", " ", names(ingr_state))
names(ingr_municipality) <- gsub("\\.", " ", names(ingr_municipality))

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### 1. Descriptive analysis
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Average cost per student
(sum(cost_data_state_municipality$`Cost per child per month`))

# Average cost per student in USD
(sum(cost_data_state_municipality$`Cost per child per month`) / 
    exchange_rate_2018)

# Percentage cost by ingredient
pct_ingredient <- cost_data_state_municipality %>% 
                     group_by(Ingredient) %>%
                     summarize(total = sum(`Cost per child per month`)) %>% 
                    mutate(pct = total/sum(total))
pct_ingredient

# Percentage of cost by municipality
ptc_agency <- cost_data_state_municipality %>% 
               group_by(`Funding agency`) %>%
               summarize(total = sum(`Cost per child per month`)) %>% 
               mutate(pct = total/sum(total), 
                      usd = total/exchange_rate_2018)
ptc_agency

adi_scholarship_usd <- ADIs_PADIN_scholarship/exchange_rate_2018
adi_compensation_usd <- c(9.3, 50.6)/exchange_rate_2018
adi_transportaton_compensation_usd <- c(22.5, 317)/exchange_rate_2018

# Supervisor's salary
min(survey_data$supervisor_gross_salary)/exchange_rate_2018
max(survey_data$supervisor_gross_salary)/exchange_rate_2018

# Supervisor's time devoted to PADIN
min(survey_data$supervisor_pct_time)
max(survey_data$supervisor_pct_time)

# Additional compensation for ADIs
adi_compensation <- survey_data %>% 
  select(municipality, ADI_additional_compensation) %>% 
  mutate(ADI_additional_compensation_us = 
           ADI_additional_compensation/exchange_rate_2018)

# ADIs' travel compensation
adi_travel_compensation <- survey_data %>% 
  select(municipality, trans_ADI_cost_aid) %>%
  mutate(trans_ADI_cost_aid_us = trans_ADI_cost_aid/exchange_rate_2018)

## Transportation
(transportation_mode <- survey_data %>% 
    group_by(trans_mode) %>% 
    summarize(n = n()) %>% mutate(freq = n / sum(n)))

## community meetings
table(survey_data$community_meetings_frequency)

## Municipality with the highest cost vs. municipality with the lowest cost
max(cost_data$municipality_gps)/min(cost_data$municipality_gps)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Table 3. Cost per child by ingredient, by month and by year
#----------------------------------------------------------------------------------------------------------------------------------------------------------
table3 <- cost_data_state_municipality %>% 
  group_by(Ingredient) %>% 
  mutate(Ingredient = factor(Ingredient, 
                             levels = c("State personnel", "Supervisors", 
                                        "Home visitors", "Training", 
                                        "Teaching kits", "Supplies", 
                                        "Transportation", "Food", 
                                        "Volunteers"))) %>% 
  summarize(cost_per_child_per_month = sum(`Cost per child per month`)) %>%
  mutate(cost_per_child_per_month_us = 
           cost_per_child_per_month/exchange_rate_2018,
         cost_per_child_per_year = 
           cost_per_child_per_month * PADIN_months, 
         cost_per_child_per_year_us = 
           cost_per_child_per_year/exchange_rate_2018,
         ptc = cost_per_child_per_month/sum(cost_per_child_per_month))

# Calculate the total for each column
total <- table3 %>% select(- Ingredient) %>%
  summarize(across(everything(), ~ sum(.x, na.rm = TRUE)))

# Combine the cost numbers for ingredients with the total
total_temp <- bind_rows(table3 %>% select(- Ingredient), total)

# Add "Total" at the end of the ingredient list
Ingredient <- rbind(table3 %>% select(Ingredient), "Total")
Ingredient <- Ingredient %>% 
  mutate(Ingredient = case_when(
    is.na(Ingredient) == TRUE ~ "Total",
    TRUE ~ Ingredient)) 

# Compile the total cost with the ingredient table
table3 <- cbind.data.frame(Ingredient, total_temp)

# Rename the column names
table3 <- table3 %>% 
  rename("Monthly cost per child in $R" = cost_per_child_per_month, 
         "Monthly cost per child in USD" = cost_per_child_per_month_us, 
         "Annual cost per child in $R" = cost_per_child_per_year, 
         "Annual cost per child in USD" = cost_per_child_per_year_us, 
         "% out of total" = ptc)

write.csv(table3, "./output/2_Tables/table3.csv")

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Table 4. Quantities and prices of ingredients
#----------------------------------------------------------------------------------------------------------------------------------------------------------
table4A <- ingr_state %>% 
  select(- Funder) %>%
  rename("Monthly price" = Price) %>%
  mutate(`Annual price` = PADIN_months * `Monthly price`, 
         `Total cost per year` = `Annual price` * Quantity,
         `Cost per child year year` = `Cost per child per month` * 
           PADIN_months)

# Calculate the total for the cost variables
total4A <- table4A %>% summarize(
  across(c("Total cost per month", "Cost per child per month", 
           "Total cost per year", "Cost per child year year"), sum), 
  # Assign the rest variables to NA
  across(setdiff(names(table4A), 
                 c("Total cost per month", "Cost per child per month", 
                   "Total cost per year", "Cost per child year year")), ~NA_real_)) %>%
  select(colnames(table4A))

total4A[1, which(colnames(total4A) == "Ingredient")] <- "Total"

table4A <- rbind.data.frame(table4A, total4A)

write.csv(table4A, "./output/2_Tables/table4A.csv", row.names = FALSE)

table4B <- ingr_municipality %>% 
  select(- Funder) %>%
  rename("Monthly price" = Price) %>%
  mutate(`Annual price` = PADIN_months * `Monthly price`, 
         `Total cost per year` = `Annual price` * Quantity,
         `Cost per child year year` = `Cost per child per month` * PADIN_months)

# Calculate the total for the cost variables
total4B <- table4B %>% summarize(
  across(c("Total cost per month", "Cost per child per month", 
           "Total cost per year", "Cost per child year year"), sum), 
  # Assign the rest variables to NA
  across(setdiff(names(table4B), 
                 c("Total cost per month", "Cost per child per month", 
                   "Total cost per year", "Cost per child year year")), ~NA_real_)) %>%
  select(colnames(table4B))

total4B[1, which(colnames(total4B) == "Ingredient")] <- "Total"

table4B <- rbind.data.frame(table4B, total4B)

write.csv(table4B, "./output/2_Tables/table4B.csv", row.names = FALSE)
#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure 1: Decomposition of total cost by funding agency: 
###           State + Municipality
#----------------------------------------------------------------------------------------------------------------------------------------------------------

data <- cost_data %>%
  # Sum up municipality cost and state cost
  mutate(cost_m_s = 
        rowSums(select(., municipality_gps, operation_cost_s), 
                na.rm = TRUE)) %>% 
  # Rank based on the cost borne by the municipality and the state
  arrange(cost_m_s) %>% 
  select(
    # Municipality name
    municipality, 
    # Average cost per student per month borne by the municipality
    municipality_gps, 
    # Average cost per student per month borne by the state
    operation_cost_s) %>%
  rename(Municipality = municipality_gps, 
         State = operation_cost_s)

# Fixed the order of the municipalities 
# based on the highest to lowest governmental cost. 
municipality_name <- data$municipality

data <- data %>%
  gather(key = `Funding agency`, 
         value = `Cost per child per month`, 
         Municipality:State) %>% 
    # Rank the municipalities by the total cost 
    # borne by the state and the municipality
  mutate(municipality = factor(municipality, levels = municipality_name), 
         `Funding agency` = factor(`Funding agency`, 
                                   levels = c("State", "Municipality"))) %>%
  arrange(municipality, `Funding agency`) %>% 
  # calculate the label position using cumsum
  group_by(municipality) %>%
  mutate(label_pos = cumsum(`Cost per child per month`) - 
           (`Cost per child per month` / 2)) 


figure1_total_cost_funding <- ggplot(data, 
                                     aes(x = municipality, 
                                         y = `Cost per child per month`, 
                                         fill = `Funding agency`)) +
  # I use position_stack with reverse = TRUE here to control
  # the order of the plot matched with my label_pos calculated
  geom_bar(position = position_stack(reverse = T), 
           stat='identity', 
           width = 0.9) + 
  # drawing the text label using label_pos which will be
  # consistent and auto adjust to midpoint when your values changes
 geom_text(data = data, aes(x = municipality, 
                            y = label_pos, 
                            label = round(`Cost per child per month`, 0)),
             color = "black", size = 3.5) + 
 # Add the totals
  geom_text(
    aes(label = round(after_stat(y), 0), group = municipality), 
    stat = 'summary', fun = sum, vjust = 0.5, hjust = - 1, size = 3.5) + 
  ylim(0, 223) + 
  coord_flip() +
  labs(title = '',
       x = '',
       y = 'Cost per child per month (Brazilian Real)', 
       caption = "") + 
  # Change the colors
  scale_fill_manual(values = colors) + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 10),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 11))

ggsave(
  "./output/1_Exhibits/figure1_total_cost_funding.png",
  figure1_total_cost_funding,
  width = 8,
  height = 8,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure 2. Decomposition of total cost by ingredient: state + municipality
#----------------------------------------------------------------------------------------------------------------------------------------------------------
data <- cost_data_state_municipality %>% 
  filter(Ingredient != "Volunteers") %>%
  mutate(Ingredient = factor(Ingredient, 
                             levels = c( "State personnel", "Supervisors", 
                                         "Home visitors", "Training", 
                                         "Teaching kits", "Supplies", 
                                         "Transportation", "Food")), 
       `Funding agency` = factor(`Funding agency`, 
                                 levels = c("State", "Municipality"))) %>%
  arrange(Ingredient, `Funding agency`) %>% 
  # calculate the label position using cumsum
  group_by(Ingredient) %>%
  mutate(label_pos = cumsum(`Cost per child per month`) - 
           (`Cost per child per month` / 2))

figure2_total_cost_ingredient <- ggplot(data, aes(fill = `Funding agency`, 
                                                y = `Cost per child per month`, 
                                                x = Ingredient)) + 
  geom_bar(position = position_stack(reverse = T), 
           stat = "identity") + 
  geom_text(aes(y = label_pos, 
                label = round(`Cost per child per month`, 1)),
            color = "black", size = 3.5) +
  labs(title = '',
       x = '',
       y = 'Cost per child per month (Brazilian Real)',
       caption = "") + 
  scale_fill_manual(values = colors) + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 10),
        # Font size of the title 
        axis.title = element_text(size = 10),
        # Font size of the legend
        legend.text = element_text(size = 10), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = -20))

ggsave(
  "./output/1_Exhibits/figure2_total_cost_ingredient.png",
  figure2_total_cost_ingredient,
  width = 8,
  height = 4.5,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure 3. Decomposition of cost borne by the municipality by ingredient: A heatmap
#----------------------------------------------------------------------------------------------------------------------------------------------------------

data <- cost_data %>% 
  rename("Supervisors" = supervisor_cost_m, 
        "Home visitors" = adi_cost_m, 
        "Training" = training_cost_m, 
        "Supplies" = office_supplies_avg_cost_m, 
        "Transportation" = trans_cost_m_gps, 
        "Food" = food_avg_cost_m) %>%
  select(municipality, `Supervisors`,
                       `Home visitors`,
                       `Training`,
                        `Supplies`,
                        `Transportation`,
                        `Food`) %>%
  gather(key = Ingredient, 
         value = `Cost per child per month`, 
         `Supervisors`:`Food`) %>% 
  mutate(municipality = factor(municipality, levels = municipality_name), 
         Ingredient = factor(Ingredient, levels = c("Supervisors",
                                                    "Home visitors",
                                                    "Training",
                                                    "Supplies",
                                                    "Transportation",
                                                    "Food")))

figure3_heatmap_m <- ggplot(data, aes(x = Ingredient, y = municipality)) + 
  geom_tile(aes(fill = `Cost per child per month`), colour = "white") + 
  scale_fill_gradient(low = "white", high = colors[2]) + 
  xlab("") +
  ylab("") + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
       # legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 11),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 10), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = -20))

ggsave(
  "./output/1_Exhibits/figure3_heatmap_m.png",
  figure3_heatmap_m,
  width = 8,
  height = 8,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure 4. Supervisor's salary vs. % of time devoted to PADIN
#----------------------------------------------------------------------------------------------------------------------------------------------------------

data <- survey_data %>% 
  select(municipality, supervisor_pct_time, 
         supervisor_gross_salary) %>%
  rename(`Percent` = supervisor_pct_time, 
         `Gross salary` = supervisor_gross_salary) %>%
  mutate(`Percent` = `Percent`/100)

figure4_supervisor <- ggplot(data, aes(x = `Percent`, 
                                       y = `Gross salary`)) + 
  geom_point(aes(), color = "darkcyan", size = 3) +  
  ggrepel::geom_text_repel(aes(label = municipality), 
                           size = 3, 
                           color = "#999999") +
  scale_x_continuous(labels = scales::percent) + 
  expand_limits(x = 0, y = 0) + 
  labs(title = "", 
       y = "Supervisors' monthly compensation from municipality", 
       x = "% of supervisors' time dedicated to PADIN", 
       caption = "") + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 11, face="bold"),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 10), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = -20))

ggsave(
  "./output/1_Exhibits/figure4_supervisor.png",
  figure4_supervisor,
  width = 8,
  height = 4.5,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure 5:The discrepancy between self-reported and transportation costs 
###         estimated with the ingredients method
#----------------------------------------------------------------------------------------------------------------------------------------------------------
data <- cost_data %>% select(municipality,  
                             trans_cost_m_gps, 
                             trans_cost_m_survey) %>%
  rename("Estimated with GIS and price data" = trans_cost_m_gps, 
         "Self-reported by program supervisors" = trans_cost_m_survey) %>%
  mutate(gap = `Estimated with GIS and price data` - 
           `Self-reported by program supervisors`) %>%
  arrange(desc(`Self-reported by program supervisors`), gap) 

municipality_ordered <- data$municipality

data <- data %>%
  gather(key = "Method", value = "cost", 
         `Estimated with GIS and price data`:
           `Self-reported by program supervisors`) %>%
  mutate(municipality = factor(municipality, 
                               levels = municipality_ordered))

figure5_dumbbell_transportation <- ggplot(data, aes(x = cost, 
                                                    y = municipality)) +
  geom_line(color = "gray") +
  geom_point(aes(color = Method), size = 2) + 
  theme_classic() + 
  labs(title = "", 
       x = "Transportation cost per student per month", 
       y = "",
       caption = "") + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 11),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 11), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = - 5))

### Descriptive statistics reported in the paper
gap_mean <- mean(abs(data$gap))/exchange_rate_2018
max <- max(abs(data$gap))/exchange_rate_2018
min <- min(abs(data$gap))

ggsave(
  "./output/1_Exhibits/figure5_dumbbell_transportation.png",
  figure5_dumbbell_transportation,
  width = 8,
  height = 8,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A1: Data inconsistency: Number of home visitors
#----------------------------------------------------------------------------------------------------------------------------------------------------------

data <- survey_data %>% 
  select(municipality, ADI_count_survey, ADI_count_validated) %>%
  left_join(online_monitoring %>% 
  select(municipality, ADI), by = "municipality") %>%
  mutate(gap = ADI - ADI_count_validated) %>%
  arrange(desc(ADI_count_validated), gap) %>%
  rename("Survey" = ADI_count_survey, 
         "M&E" = ADI_count_validated, 
         "Online monitoring system" = ADI)

municipality_ordered <- data$municipality

data <- data %>%
  gather(key = "Source", value = `ADI count`, 
         "Survey":"Online monitoring system") %>%
  mutate(Source = factor(Source, 
                         levels = c("Survey", "M&E", 
                                    "Online monitoring system")), 
         municipality = factor(municipality, 
                               levels = municipality_ordered))

figureA1_ADI_consistency <- ggplot(data, 
                                   aes(x = `ADI count`, 
                                       y = municipality)) +
  geom_line(color = "gray") +
  geom_point(aes(color = Source, shape = Source, size = Source)) + 
  scale_size_manual(values = c(3, 2, 2)) + 
  theme_classic() + 
  labs(title = "", 
       x = "Number of home visitors", 
       y = "",
       caption = "") + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 11),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 11), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = - 5))

ggsave(
  "./output/1_Exhibits/figureA1_ADI_consistency.png",
  figureA1_ADI_consistency,
  width = 8,
  height = 6.5,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A2: Data inconsistency: Number of children served
#----------------------------------------------------------------------------------------------------------------------------------------------------------

data <- survey_data %>% 
  select(municipality, children_count_served) %>%
  left_join(online_monitoring %>% select(municipality, children), 
            by = "municipality") %>% 
  mutate(gap = children - children_count_served) %>%
  arrange(desc(children_count_served), desc(gap)) %>%
  rename("Estimated based on program design" = children_count_served, 
         "Online monitoring system" = children)

municipality_ordered <- data$municipality

data <- data %>%
  gather(key = "Source", value = `Children served count`, 
         "Estimated based on program design":"Online monitoring system") %>%
  mutate(Source = factor(Source, 
                         levels = c("Estimated based on program design", 
                                    "Online monitoring system")), 
         municipality = factor(municipality, levels = municipality_ordered))

figureA2_children_consistency <- ggplot(data, 
                                        aes(x = `Children served count`, 
                                            y = municipality)) +
  geom_line(color = "gray") +
  geom_point(aes(color = Source, shape = Source, size = Source)) + 
  scale_size_manual(values = c(3, 2)) + 
  theme_classic() + 
  labs(title = "", 
       x = "Number of children served", 
       y = "",
       caption = "") + 
  theme(legend.position = "bottom")

ggsave(
  "./output/1_Exhibits/figureA2_children_consistency.png",
  figureA2_children_consistency,
  width = 8,
  height = 6.5,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A3. Decomposition of cost borne by the state by ingredient
#----------------------------------------------------------------------------------------------------------------------------------------------------------
data <- cost_data_state_municipality %>%
  filter(`Funding agency` == "State") %>%
  mutate(percent = `Cost per child per month`/
           sum(`Cost per child per month`)) %>%
  mutate(Ingredient = factor(Ingredient, 
                             levels = c("State personnel", 
                                        "Supervisors", 
                                        "Home visitors",
                                        "Training", 
                                        "Teaching kits", 
                                        "Food"))) %>% 
  arrange(Ingredient) %>%
  # calculate the label position using cumsum
  mutate(label_pos = cumsum(percent) - (percent / 2), 
         label1 = case_when(Ingredient == "Teaching kits" ~ NA, 
                            TRUE ~ Ingredient), 
         label2 = case_when(Ingredient == "Teaching kits" ~ Ingredient, 
                            TRUE ~ NA))

figureA3_decomposition_state_cost <- ggplot(data, 
                                            aes(x = `Funding agency`, 
                                                y = percent, 
                                                fill = Ingredient)) +
  # I use position_stack with reverse = TRUE here to control
  # the order of the plot matched with my label_pos calculated
  geom_bar(position = position_stack(reverse = T), 
           stat='identity', 
           width = 0.5, 
           color = "black") + 
  # drawing the text label using label_pos which will be
  # consistent and auto adjust to midpoint when your values changes
  geom_text(aes(y = label_pos, 
                label = paste0(round(percent, 2)*100, "%")),
            color = "white", size = 3.5) +
  geom_text(aes(y = label_pos, x = 0.6, label = label1),
            color = "black", size = 3.5) + 
  geom_text(aes(y = label_pos, x = 1.4, label = label2),
            color = "black", size = 3.5) + 
  coord_flip() +
  labs(title = '',
    x = '',
    y = '', 
    caption = "") + 
  theme(legend.position = "none") + 
  scale_fill_manual(values = color_palette_blue) +
  theme(legend.position = "none", 
        axis.line = element_blank(),
        axis.ticks = element_blank(),
        axis.text = element_blank(),
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        legend.title = element_blank(), 
        axis.title = element_blank())

ggsave(
  "./output/1_Exhibits/figureA3_decomposition_state_cost.png",
  figureA3_decomposition_state_cost,
  width = 8,
  height = 2,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A4: Decomposition of total cost by percentage: State + Municipality
###            % of municipality cost out of the total of the state and 
###            the municipality cost
#----------------------------------------------------------------------------------------------------------------------------------------------------------

# Estimate the weighted average across all municipalities
state_municipality_across_all <- cost_data_state_municipality %>%
  # Remove community cost
  filter(`Funding agency` != "Community") %>%
  group_by(`Funding agency`) %>% 
  summarize(total_cost = sum(`Cost per child per month`))

state_municipality_across_all <- bind_cols(c("All", "All"), 
                                           state_municipality_across_all)
colnames(state_municipality_across_all) <- c("municipality", "Funding agency",          
                                             "Cost per child per month")

state_municipality_across_all <- state_municipality_across_all %>%
  mutate(`Funding agency` = factor(`Funding agency`, 
                                   levels = c("State", "Municipality"))) %>%
  arrange(`Funding agency`)

# Prepare the data for the graph
data <- cost_data %>%
  # Sum up municipality cost and state cost
  mutate(cost_m_s = rowSums(select(., municipality_gps, 
                                   operation_cost_s), na.rm = TRUE)) %>% 
  # Rank based on the cost borne by the municipality and the state
  arrange(cost_m_s) %>% select(
    # Municipality name
    municipality, 
    # Average cost per student per month borne by the municipality
    municipality_gps, 
    # Average cost per student per month borne by the state
    operation_cost_s) %>%
  rename(Municipality = municipality_gps, 
         State = operation_cost_s) 

# Fixed the order of the municipalities 
# based on the highest to lowest governmental cost. 
municipality_name <- data$municipality

data <- data %>%
  gather(key = `Funding agency`, 
         value = `Cost per child per month`, 
         Municipality:State) %>% 
  # Rank the municipalities by the total cost borne by the state and the municipality
  mutate(municipality = factor(municipality, 
                               levels = municipality_name), 
         `Funding agency` = factor(`Funding agency`, 
                                   levels = c("State", "Municipality"))) %>%
  arrange(municipality, `Funding agency`) %>% 
  rbind.data.frame(state_municipality_across_all) %>%
  group_by(municipality) %>% 
  mutate(percent = `Cost per child per month`/
           sum(`Cost per child per month`), 
         label_pos_percent = cumsum(percent) - (percent/ 2))

figureA4_total_cost_percentage <- ggplot(data, 
                                         aes(x = municipality, 
                                             y = percent, 
                                             fill = `Funding agency`)) +
  # I use position_stack with reverse = TRUE here to control
  # the order of the plot matched with my label_pos_percent calculated
  geom_bar(position = position_stack(reverse = T), 
           stat='identity', 
           width = 0.9) + 
  # drawing the text label using label_pos_percent which will be
  # consistent and auto adjust to midpoint when your values changes
  geom_text(aes(y = label_pos_percent, 
                label = paste0(round(percent, 2)*100, "%")),
            color = "black", size = 3.5) +
  coord_flip() + 
  geom_hline(yintercept = data$percent[data$municipality == "All" & 
                                         data$`Funding agency` == "State"], 
             linetype = "dashed", 
             color = "blue", linewidth = 1) + 
  labs(title = '',
       x = '',
       y = '',
       caption = "") + 
  theme(legend.position = "bottom") + 
  scale_fill_manual(values = colors) + 
  scale_fill_manual(values = colors) + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 10),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 11), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = -20))

ggsave(
  "./output/1_Exhibits/figureA4_total_cost_percentage.png",
  figureA4_total_cost_percentage,
  width = 8,
  height = 8,
  units = "in",  
  dpi = 1200
)

#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A5:Correlation between GDP per capita and cost per child per month of PADIN
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Create the per capita expenditure variable
# this part of the coee is commented out as the data used couldn't be published. 
# see more information on the README file. 

# municipality_statistics <- municipality_statistics %>% 
#   mutate(gdp_per_capita = gpd_thousandR * 1000 / population) %>%
#   left_join(y = cost_data %>% select(municipality, 
#                                      municipality_gps, total_m_s), 
#             by = "municipality")
# 
# cor.test(x = municipality_statistics$gdp_per_capita, 
#          y = municipality_statistics$municipality_gps)
# 
# figureA5_corr_spending_wealth <- ggplot(municipality_statistics, 
#                                aes(x = gdp_per_capita, 
#                                    y = municipality_gps)) + 
#   geom_point(aes(), color = "orange", size = 3) +  
#   # ggrepel::geom_text_repel(aes(label = municipality), size = 3) + 
#   # expand_limits(x = 0, y = 0) + 
#   geom_smooth(method=lm) + 
#   #ggpubr::stat_cor(method = "pearson") + 
#   labs(title = "", 
#        x = "Gross domestic product per capita in 2018", 
#        y = "Cost per child per month borne by the municipality", 
#        caption = "") + 
#   theme_classic()
# 
# ggsave(
#   "./output/1_Exhibits/figureA5_corr_spending_wealth.png",
#   figureA5_corr_spending_wealth,
#   width = 8,
#   height = 4.5,
#   units = "in",  
#   dpi = 1200
# )


#----------------------------------------------------------------------------------------------------------------------------------------------------------
### Figure A6: What would be the cost per student if we only rely on financial records?
#----------------------------------------------------------------------------------------------------------------------------------------------------------
# Data from the state budget
training_s <- state_budget_original$Cost[1]
teaching_kits_s <- state_budget_original$Cost[2] + 
  state_budget_original$Cost[4]
food_s <- state_budget_original$Cost[3]
municipal_personnel <- state_budget_original$Cost[5]
state_personnel <- state_budget_original$Cost[6]

state_reported <- bind_cols(
  c("Training", "Teaching kits", "Food", 
    "Supervisors and home visitors", 
    "State personnel"), 
  c(training_s, teaching_kits_s, food_s, 
    municipal_personnel, state_personnel))

colnames(state_reported) <- c("Ingredient", "total_cost")

state_reported <- state_reported %>% 
  mutate(`Cost per child per month` = total_cost/PADIN_months/n_children_2018, 
         `Funding agency` = "State")

# Data from the budgets of 20 municipalities
municipality_budget_summary <- municipality_budget %>%
  mutate(category = case_when(
    category == "Fuel" ~ "Transportation", 
    category == "Vehicle rental" ~ "Transportation", 
    category == "Supervisor's aggregate car" ~ "Transportation", 
    category == "Transport for training" ~ "Transportation", 
    category == "Fuel for the supervisor to monitor visits of ADIs in families" ~ "Transportation", 
    category == "Vehicle maintenance" ~ "Transportation",
    TRUE ~ category)) %>%
  filter(category %in% c("Food", "Office supplies", "Transportation")) %>%
  group_by(municipality, month, category) %>%
  # Total cost by category and month for each municipality
  summarize(sum = sum(cost)) %>% 
  ungroup %>% group_by(municipality, category) %>%
  summarize(avg_monthly_cost = mean(sum, na.rm = TRUE))

food <- left_join(
  survey_data %>% select(municipality, children_count_served), 
  municipality_budget_summary %>% filter(category == "Food"), 
            by = "municipality") %>%
  # Calculate the average cost per child per month
  mutate(food_avg_cost_m = avg_monthly_cost / children_count_served, 
         children_served_pct = children_count_served/sum(children_count_served)) %>%
  mutate(
  # Impute the missing values using the mean of the observed values
    food_avg_cost_m = ifelse(is.na(food_avg_cost_m) == TRUE, 
      mean(food_avg_cost_m, na.rm = TRUE), food_avg_cost_m)) %>%
  summarize(food_avg_cost_m = sum(food_avg_cost_m * children_served_pct))

office_supplies <- left_join(
  survey_data %>% select(municipality, children_count_served), 
  municipality_budget_summary %>% filter(category == "Office supplies"), 
      by = "municipality") %>%
  mutate(
    children_served_pct = children_count_served/sum(children_count_served), 
    office_supplies_avg_cost_m = avg_monthly_cost / children_count_served, 
    # Impute the missing values using the mean of the observed values
    office_supplies_avg_cost_m = ifelse(is.na(office_supplies_avg_cost_m) == TRUE, 
                                        mean(office_supplies_avg_cost_m, na.rm = TRUE), 
                                        office_supplies_avg_cost_m)) %>%
  summarize(office_supplies_avg_cost_m = sum(office_supplies_avg_cost_m * children_served_pct))

trans <- left_join(
  survey_data %>% select(municipality, children_count_served), 
  municipality_budget_summary %>% filter(category == "Transportation"), 
  by = "municipality") %>%
  mutate(
    children_served_pct = children_count_served/sum(children_count_served), 
    trans_avg_cost_m = avg_monthly_cost / children_count_served, 
    # Impute the missing values using the mean of the observed values
    trans_avg_cost_m = ifelse(is.na(trans_avg_cost_m) == TRUE, 
                              mean(trans_avg_cost_m, na.rm = TRUE), 
                              trans_avg_cost_m)) %>%
  summarize(trans_avg_cost_m = sum(trans_avg_cost_m * children_served_pct))

municipality_reported <- bind_cols(
  c("Food", "Supplies", "Transportation"), 
  c(food[[1]], office_supplies[[1]], trans[[1]]))

colnames(municipality_reported) <- c("Ingredient", "Cost per child per month")

municipality_reported <- municipality_reported %>% 
  mutate(`Funding agency` = "Municipality")

reported <- rbind(state_reported %>% select(- total_cost), 
                  municipality_reported) %>%
  mutate(Method = "Financial records")

supervisor_hw <- cost_data_state_municipality %>% 
  filter(Ingredient %in% c("Supervisors", "Home visitors")) %>%
  group_by(`Funding agency`) %>% summarize(
    `Cost per child per month` = sum(`Cost per child per month`))

supervisor_hw <- bind_cols(
  c("Supervisors and home visitors", 
    "Supervisors and home visitors"),
  supervisor_hw[2], 
  supervisor_hw[1])

colnames(supervisor_hw) <- c("Ingredient", 
                             "Cost per child per month", 
                             "Funding agency")

estimated <- cost_data_state_municipality %>% 
  filter(!Ingredient %in% c("Supervisors", 
                            "Home visitors", 
                            "Volunteers")) %>%
  bind_rows(supervisor_hw) %>% 
  mutate(Method = "Ingredients method")

data <- bind_rows(reported, estimated) %>%
  spread(key = Method, value = `Cost per child per month`) %>%
  mutate(
    # If the state or the municipalities did not report the cost 
    # of an ingredient, impute it as 0. 
    `Financial records` = case_when(is.na(`Financial records`) == TRUE ~ 0, 
                                  TRUE ~ `Financial records`)) %>% 
  gather(key = Method, value = `Cost per child per month`, 
         `Ingredients method`:`Financial records`) %>%
  mutate(
    Ingredient = factor(Ingredient, 
                        levels = c("Food", "Transportation", 
                                   "Supplies", "Teaching kits",
                                   "Training", 
                                   "Supervisors and home visitors", 
                                   "State personnel")), 
    `Funding agency` = factor(`Funding agency`, 
                              levels = c("State", "Municipality")), 
     Method = factor(Method, levels = c("Ingredients method", 
                                        "Financial records")))
  
figureA6_discrepancy <- ggplot(data, aes(x = `Cost per child per month`, 
                                         y = Ingredient)) +
  geom_line(color = "gray") + 
  geom_point(aes(color = Method, 
                 shape = Method, 
                 size = Method)) + 
  scale_size_manual(values = c(3, 2)) + 
  facet_wrap( ~ `Funding agency`) +
  labs(title = '',
       x = 'Cost per child per month',
       y = '',
       caption = "") + 
  scale_fill_manual(values = colors) + 
  theme_classic() + 
  theme(legend.position = "bottom", 
        panel.background = element_blank(), 
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"), 
        legend.title = element_blank(), 
        # Font size of the axis
        axis.text = element_text(size = 10),
        # Font size of the title 
        axis.title = element_text(size = 11),
        # Font size of the legend
        legend.text = element_text(size = 11), 
        # Shorten the distance between the axis and the legend
        legend.margin=margin(t = 0),
        # Shorten the space between lines in the y-axis title
        axis.title.y = element_text(lineheight = 0.8))

ggsave(
  "./output/1_Exhibits/figureA6_discrepancy.png",
  figureA6_discrepancy,
  width = 8,
  height = 4,
  units = "in",  
  dpi = 1200
)